import { StringTask } from '../types';
import { DiffResult } from '../../../typings';
import { EmptyTask } from './task';
export declare function diffSummaryTask(customArgs: string[]): StringTask<DiffResult> | EmptyTask;
export declare function validateLogFormatConfig(customArgs: unknown[]): EmptyTask | void;
