import { Maybe, StringTask } from '../types';
export declare enum CheckRepoActions {
    BARE = "bare",
    IN_TREE = "tree",
    IS_REPO_ROOT = "root"
}
export declare function checkIsRepoTask(action: Maybe<CheckRepoActions>): StringTask<boolean>;
export declare function checkIsRepoRootTask(): StringTask<boolean>;
export declare function checkIsBareRepoTask(): StringTask<boolean>;
