import { type DOMNode } from './dom.js';
import type Output from './output.js';
declare const renderBorder: (x: number, y: number, node: DOMNode, output: Output) => void;
export default renderBorder;
