export declare enum DiffNameStatus {
    ADDED = "A",
    COPIED = "C",
    DELETED = "D",
    MODIFIED = "M",
    RENAMED = "R",
    CHANGED = "T",
    UNMERGED = "U",
    UNKNOWN = "X",
    BROKEN = "B"
}
export declare function isDiffNameStatus(input: string): input is DiffNameStatus;
