/*
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

#pragma once

struct Layout {
  double left;
  double right;

  double top;
  double bottom;

  double width;
  double height;
};
