import { MergeResult } from '../../../typings';
import { StringTask } from '../types';
import { EmptyTask } from './task';
export declare function mergeTask(customArgs: string[]): EmptyTask | StringTask<MergeResult>;
