import type { AnsiCode } from "./tokenize.js";
export declare const ESCAPES: Set<number>;
export declare const CSI: number;
export declare const OSC: number;
export declare const endCodesSet: Set<string>;
export declare const linkCodePrefix = "\u001B]8;";
export declare const linkCodePrefixCharCodes: number[];
export declare const linkCodeSuffix = "\u0007";
export declare const linkCodeSuffixCharCode: number;
export declare const linkEndCode: string;
export declare function getLinkStartCode(url: string, params?: Record<string, string>): string;
export declare function getEndCode(code: string): string;
export declare function ansiCodesToString(codes: AnsiCode[]): string;
/** Check if a code is an intensity code (bold or dim) - these share endCode 22m but can coexist */
export declare function isIntensityCode(code: AnsiCode): boolean;
