export type TerminalSize = {
	columns: number;
	rows: number;
};

/**
Reliably get the terminal window size.

@example
```
import terminalSize from 'terminal-size';

terminalSize();
//=> {columns: 143, rows: 24}
```
*/
export default function terminalSize(): TerminalSize;
