import type { SimpleGit } from '../../../typings';
export declare enum GitConfigScope {
    system = "system",
    global = "global",
    local = "local",
    worktree = "worktree"
}
export default function (): Pick<SimpleGit, 'addConfig' | 'getConfig' | 'listConfig'>;
