export default {
  commands: 'Commands',
  'code-review': 'Code Review',
  'followup-suggestions': 'Followup Suggestions',
  'tool-use-summaries': 'Tool-Use Summaries',
  'markdown-rendering': 'Markdown Rendering',
  'sub-agents': 'SubAgents',
  arena: 'Agent Arena',
  skills: 'Skills',
  memory: 'Memory',
  headless: 'Headless Mode',
  'dual-output': 'Dual Output',
  checkpointing: {
    display: 'hidden',
  },
  'approval-mode': 'Approval Mode',
  mcp: 'MCP',
  lsp: 'LSP (Language Server Protocol)',
  'token-caching': 'Token Caching',
  sandbox: 'Sandboxing',
  language: 'i18n',
  channels: 'Channels',
  hooks: 'Hooks',
  'status-line': 'Status Line',
  'scheduled-tasks': 'Scheduled Tasks',
  tips: 'Contextual Tips',
};
