import { type Writable } from 'node:stream';
export declare const bsu = "\u001B[?2026h";
export declare const esu = "\u001B[?2026l";
export declare function shouldSynchronize(stream: Writable): boolean;
